@@ -1,5 +1,8 @@
 #!/usr/bin/env bash
 
+export SECRET_KEY=1234
+export SQLITE3_DIR=${HOME}/prestoweb_data
+
 uwsgi --http-socket 0.0.0.0:8001 \
     --master \
     --workers 1 \
